
# Slot: number_of_strongly_connected_components

The number of distinct components that consist of activities that are connected (directly or indirectly) via causal connections. Most models will consist of a single SCC. Some models may consist of two or more "islands" where there is no connection from one island to another.

URI: [gocam:queryIndex__number_of_strongly_connected_components](https://w3id.org/gocam/queryIndex__number_of_strongly_connected_components)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
